@@ -1,5 +1,5 @@
 import cmd, sys, traceback, os, shlex
-from .http import login, tasks, submissions, submission_protocol, submit_solution, status, scores, compile_error, submission_source, compiler_list, submission_stats, has_feature, contest_list
+from .http import login_type, login, tasks, submissions, submission_protocol, submit_solution, status, scores, compile_error, submission_source, compiler_list, submission_stats, has_feature, contest_list
 from .error import EJError
 import ejcli.commands
 
@@ -38,6 +38,19 @@ class BruteCMD(cmd.Cmd):
         import getpass
         x = getpass.getpass()
         self.url, self.cookie = login(data[0], data[1], x)
+    def do_anonlogin(self, cmd):
+        """
+        usage: anonlogin <login_page_url>
+
+        Perform an anonymous login to CMS.
+        """
+        data = cmd.split(' ')
+        if len(data) != 1:
+            return self.do_help('login')
+        url = data[0]
+        if 'pass' not in login_type(url):
+            raise EJError("Anonymous login is not supported")
+        self.url, self.cookie = login(url, None, None)
     def do_logout(self, cmd):
         """
         usage: logout
@@ -116,8 +129,8 @@ class BruteCMD(cmd.Cmd):
         sp = cmd.split()
         if len(sp) != 3:
             return self.do_help('submit')
-        tasks = tasks(self.url, self.cookie)
-        try: task_id = next(i.id for i in tasks if i.short_name == sp[0])
+        task_list = tasks(self.url, self.cookie)
+        try: task_id = next(i.id for i in task_list if i.short_name == sp[0])
         except StopIteration:
             raise EJError("No such task.")
         if not sp[1].isnumeric():
@@ -165,10 +178,16 @@ class BruteCMD(cmd.Cmd):
         Show scores for each task if subm_id is not specified.
         """
         if isspace(cmd):
-            ans = scores(self.url, self.cookie)
+            if has_feature(self.url, self.cookie, 'scores', 'total'):
+                ans = scores(self.url, self.cookie, total=True)
+            else:
+                ans = scores(self.url, self.cookie)
             print('Task\tScore')
             for k, v in ans.items():
-                print(k+'\t'+str(v))
+                if k is not True:
+                    print(k+'\t'+str(v))
+            if True in ans:
+                print('Total score:', ans[True])
         else:
             if len(cmd.split()) != 1:
                 return self.do_help('scores')
@@ -176,7 +195,7 @@ class BruteCMD(cmd.Cmd):
             except ValueError:
                 return self.do_help('scores')
             for i in submissions(self.url, self.cookie):
-                if i.id == int(splitted[0]):
+                if i.id == subm_id:
                     print(i.score)
     def do_source(self, cmd):
         """
@@ -275,11 +294,9 @@ class BruteCMD(cmd.Cmd):
         task = cmd.strip()
         if not task:
             return self.do_help('compilers')
-        tasks = task_list(self.url, self.cookie)
-        ids = task_ids(self.url, self.cookie)
         try:
-            prob_id = ids[tasks.index(task)]
-        except (ValueError, IndexError):
+            prob_id = next(i.id for i in tasks(self.url, self.cookie) if i.short_name == task)
+        except StopIteration:
             raise EJError("No such task")
         ans = compiler_list(self.url, self.cookie, prob_id)
         print("ID\tCompiler")
